.. Debate Wiki documentation master file, created by
   sphinx-quickstart on Fri Jul 23 21:45:43 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Debate Wiki's documentation!
=======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Module Reference <api/modules>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
